Learn R Programming

petro.One (version 0.2.3)

as_named_list: Take objects and create a list using their names

Description

This avoids retyping the name of the object as in a list

Usage

as_named_list(...)

Arguments

...

additional parameters